pub struct Decoded<T: ?Sized, D> { /* private fields */ }Expand description
A decoded value and the decoder which contains it.
Implementations
Sourceimpl<T: ?Sized, D> Decoded<T, D>
impl<T: ?Sized, D> Decoded<T, D>
Sourcepub fn into_raw_parts(self) -> (*mut T, D)
pub fn into_raw_parts(self) -> (*mut T, D)
Returns the raw pointer and decoder used to create this Decoded.
Sourcepub fn take(self) -> T::Natural
pub fn take(self) -> T::Natural
Takes the value out of this Decoded and calls FromWire::from_wire on the taken value to
convert it to the default natural type.
This consumes the Decoded.